@@ -1,9 +1,9 @@
-
+import enum
 from enum import Enum, unique
 
 
 @unique
-class EnumBarType(Enum):
+class EnumBarType(enum.IntEnum):
     tick = 0
     second = 1
     minute = 2
