@@ -269,12 +269,14 @@ class BaseBarHelper:
         end_trading_day = TradingDayHelper.get_last_trading_day(end_date)
         lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_day)
         for trading_day in lst_trading_days:
-            time_slice = TimeSlice(begin_time=datetime.timedelta(hours=0, minutes=0, seconds=0), end_time=datetime.timedelta(hours=23, minutes=59, seconds=59))
+            time_slice = TimeSlice(begin_time=datetime.timedelta(hours=0, minutes=0, seconds=0), end_time=datetime.timedelta(hours=23, minutes=59, seconds=0))
             lst_trading_time_slices = [time_slice]
             lst_time_slices = BaseBarHelper.create_time_slice(lst_trading_time_slices, 0, interval, bar_type)
-            lst_date_time_slices = BaseBarHelper.create_date_time_slice(trading_day, lst_time_slices)
-            for dateTimeSlice in lst_date_time_slices:
-                lst_all_date_time_slices.append(dateTimeSlice)
+            for time_slices in lst_time_slices:
+                date_time_slices = DateTimeSlice()
+                date_time_slices.begin_time = trading_day + time_slices.begin_time
+                date_time_slices.end_time = trading_day + time_slices.end_time
+                lst_all_date_time_slices.append(date_time_slices)
 
         return lst_all_date_time_slices
 
